<?php

use yii\helpers\Html;

/* @var $this yii\web\View */
/* @var $model frontend\models\Activities */

$this->title = 'Update Absence: ' . ' ' . $model->jobno;

?>
<div class="activities-update">


    <?= $this->render('_absence', [
        'model' => $model,
    ]) ?>

</div>
