<?php

use yii\helpers\Html;



/* @var $this yii\web\View */
/* @var $model frontend\models\Activities */

?>
<table width="100%">
<tr>
	<td align="left" style="border: none" >
	<img src="https://my.inlinetrack.co.uk/images/InlineLogo.png"/>
	</td>
	<td align="right" style="border: none">
		<img src="https://my.inlinetrack.co.uk/images/homesafe.jpg" width="12.5%" height="auto" >
	</td>
</tr>
</table>
<div style="font-family: Gill Sans MT; font-size: 24px ">
<p align="center" style="font-family: Gill Sans MT"><b>Inline Track</b></p><br>
<p align="center" class="">ALUMINO SYSTEM</p>

</div>
<br>
<br>
<table width="100%" style="font-family: Gill Sans MT; font-size: 18px; border: none" >
<tr><td align="center" style="border: none" >Client</td><td align="center" style="border: none" ><?= $model->account ? $model->account->account_name : null ?> </td></tr>
<tr><td align="center" style="border: none" >Number of Sheets</td><td align="center" style="border: none" ><?= $sheetcount ?> </td></tr>
<tr><td height="400px" style="border: none" colspan="2"> </td></tr>		
</table>		
<br>
<br>
<br>


<table width="100%" style="border: none">
<tr>
	<td align="left" style="border: none">
	<img src="https://my.inlinetrack.co.uk/images/RISQS.png"/>
	</td>
	<td align="right" style="border: none">
		<img src="https://my.inlinetrack.co.uk/images/ciras.png" width="12.5%" height="auto">
	</td>
</tr>
</table>	
    <?php foreach ($dtpdf as $key => $pdf){ ?>
		<pagebreak orientation='portrait'/><div>
		<?= $this->render($pdf->data->viewLayout, ["model" => $pdf->data]); ?>
	<?php } ?>
</div>
