<?php

use yii\helpers\Html;
use yii\widgets\ActiveForm;

/* @var $this yii\web\View */
/* @var $model frontend\models\ActivitiesSearch */
/* @var $form yii\widgets\ActiveForm */
?>

<div class="activities-search">

    <?php $form = ActiveForm::begin([
        'action' => ['index'],
        'method' => 'get',
    ]); ?>

    <?= $form->field($model, 'id') ?>

    <?= $form->field($model, 'welder') ?>

    <?= $form->field($model, 'travelstarttime') ?>

    <?= $form->field($model, 'starttime') ?>

    <?= $form->field($model, 'finishtime') ?>

    <?php // echo $form->field($model, 'travelfinishtime') ?>

    <?php // echo $form->field($model, 'shiftlength') ?>

    <?php // echo $form->field($model, 'company') ?>

    <?php // echo $form->field($model, 'assistant') ?>

    <?php // echo $form->field($model, 'contact') ?>

    <?php // echo $form->field($model, 'contactno') ?>

    <?php // echo $form->field($model, 'location') ?>

    <?php // echo $form->field($model, 'createdby') ?>

    <?php // echo $form->field($model, 'createdon') ?>

    <?php // echo $form->field($model, 'noofwelds') ?>

    <?php // echo $form->field($model, 'contactemail') ?>

    <?php // echo $form->field($model, 'date') ?>

    <?php // echo $form->field($model, 'noofshifts') ?>

    <?php // echo $form->field($model, 'attachments') ?>

    <div class="form-group">
        <?= Html::submitButton('Search', ['class' => 'btn btn-primary']) ?>
        <?= Html::resetButton('Reset', ['class' => 'btn btn-primary']) ?>
    </div>

    <?php ActiveForm::end(); ?>

</div>
