<?php

use yii\helpers\Html;


/* @var $this yii\web\View */
/* @var $model frontend\models\Activities */

$this->title = 'Create Absence';
$this->params['breadcrumbs'][] = ['label' => 'Activities', 'url' => ['index']];
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="activities-create">

    <h1><?= Html::encode($this->title) ?></h1>

    <?= $this->render('_absence', [
        'model' => $model,
    ]) ?>

</div>
