<?php
use yii\helpers\Html;
use yii\helpers\ArrayHelper;
use modules\custom\models\Accounts;
use yii\helpers\Url;
?>
<style>
.SignatureLine1 {
    align: left;
    font: Calibri;
    font-size: 10pt;
    font-family: Calibri;
}

.body {
    font-family: Calibri;
    font-size: 11pt;
    font-style: oblique;
}

.Table {
    width: 100%;
    margin-right: none;
    margin-bottom: none;
    border-color: #000000;
    line-height: 12pt;
    padding: 0 0 0 0;
}

.DarkerBlue {
    border-color: #000000;
    background-color: #8DB4E2;
    font-family: 'Gill Sans MT';
    font-size: 11pt;
    border: 1px;
    border-collapse: collapse;
}

.Title {
    font-family: 'Gill Sans MT';
    font-size: 14pt;
    font-weight: Bold;
    border: 0px;
    border-collapse: collapse;
    text-align: center;
    padding-bottom: none;
    padding-top: none;
}

.DarkerBlueC {
    border-color: #8DB4E2;
    background-color: #8DB4E2;
    font-family: 'Gill Sans MT';
    font-size: 12pt;
    border: 0px;
    border-collapse: collapse;
    text-align: center;
}
</style>


<div>
    <div class='body'>
        <p>CANCELLED SHIFT </p>
        <p>Please see the attached file</p>
        <br>
        <div class='SignatureLine1'>
            <img src='http://crm.inlinetrack.co.uk/web/images/Inline.png' /><br>
            Welding the Rail Networks Together
            <br>
            <img src='http://crm.inlinetrack.co.uk/web/images/RISQS.png' />
            <br>
            <img src='http://crm.inlinetrack.co.uk/web/images/Lifesaving.png' />
            <br>
            Disclaimer Notice<br>
            This email and any files transmitted with it are confidential and intended solely for the use of those to
            whom they are addressed. Any views or opinions expressed are solely of the author unless otherwise
            specifically stated.<br>

            If you have received this email in error please advise the sender and then delete it.<br>

            The sender does not accept any responsibility for any virus that may evade detection and be transmitted with
            this message or any attachments.<br>

            Please consider the environment - do you need to print this e-mail?<br>
        </div>
    </div>