<?php
use yii\helpers\Html;
use yii\helpers\Url;
use yii\widgets\ActiveForm;

?>


<?php $form = ActiveForm::begin(); ?>

<div>
	Name:     <?= $model->welder?><br />
	Start Date:<?= $model->sdate ?><br />
	Return Date:<?= $model->edate ?><br />
		
	Reason for Absence:<br />
			<?= $model->jobstatus ?><br />
			<?= $model->details ?><br />
	

    <?php ActiveForm::end(); ?>
   
<?= Html::a('Update', ['absupdate', 'id' => $model->id], ['class' => 'btn btn-primary']) ?> 	
<?= Html::a('Clone', ['absclone', 'id' => $model->id], ['class' => 'btn btn-primary']) ?> 	
    </div>

