<style>
.Central{
	width: 100%; 
		}
</style>

<div class="Central" align="center"> 
<p><?php
//$email = implode(',', $email);
 //$emails = implode(',', $email->personalemail);
 //print_r($email)
 ?></p>
<p style="font-size: 22pt"><b>Your Email has been sent</b></p>
</div>