<?php
use yii\helpers\Html;
?>
<style>
.green{
background-color: limegreen;	
}
.red{
background-color: red;
}
	
</style> 
<?php
Yii::warning($model);
$model = !array($model) && is_array(json_decode($model, 1)) == true ? json_decode($model, 1) : $model;
$class = null;
if ($model['message'] == 'Message Recieved and Queued' || $model['message'] == 'Message Sent') {
        $class = 'green';
    } else {
        $class = 'red';
    } 
?>

<div class="jumbotron <?= $class ?>">
Current Status:<br />
<?=  $model['message'] ?><br />
<?= HTML::A('Check Again', ['activities/getmupdate', 'emailid' => $emailid], ['class' => 'btn btn-primary']); ?>
</div>

