<?php

namespace modules\activities;

class Module extends \yii\base\Module
{
    public $controllerNamespace = 'modules\activities\controllers';

    public function init()
    {
        parent::init();
        
        \Yii::$app->urlManager->addRules([
            '<controller:activities>' => 'activities/<controller>/index',
            '<controller:activities>/<action:[\w\-]+>' => 'activities/<controller>/<action>',
        ]);
        // custom initialization code goes here
    }
}