<div class="card">
    <div class="card-header">
        Administration
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-12">
                <?php foreach($dataModel as $attfield => $attvalue){ ?>
                    <?= $form->field($dataModel, $attfield)->textInput(['class' => 'form-control']) ?>
                <?php } ?>
            </div>
        </div>
    </div>
</div>