<?php
use yii\helpers\Html;
use yii\widgets\Pjax;
?>
<div class="notes">
	<div class="panel panel-default">
		<div class="panel-heading">Notes</div>
		<div class="panel-body">
			<?php if ($model->renotes) {?>
				<?php foreach ($model->renotes as $notes) { ?>
					<div class="row">
						<div class="col-md-12">
							<p><?= $notes->note ?></p>
						</div>
					</div>
					<div class="row">
						<div class="col-sm-1 DarkerBlue">Status</div>
						<div class="col-sm-2"><?= $notes->status ?></div>
						<div class="col-sm-1 DarkerBlue">Type</div>
						<div class="col-sm-2"><?= $notes->type ?></div>
						<div class="col-sm-1 DarkerBlue">Urgency</div>
						<div class="col-sm-2"><?= $notes->urgency ?></div>
					</div>
					
					<div class="row " style="border-bottom: 2px solid black">
						<div class="col-sm-1 DarkerBlue">Created By</div>
						<div class="col-sm-2"><?= $notes->createdby->fullname ?></div>
						<div class="col-sm-1 DarkerBlue">Created At</div>
						<div class="col-sm-2"><?= $notes->created_at ?></div>
						<div class="col-sm-1 DarkerBlue">Updated By</div>
						<div class="col-sm-2"><?= $notes->updatedby->fullname ?></div>
						<div class="col-sm-1 DarkerBlue">Updated at</div>
						<div class="col-sm-2"><?= $notes->updated_at ?></div>
					</div>
					<div class="row">&nbsp;</div>
				<?php } ?>
			<?php } ?>
		</div>
	</div>

</div>
		
	
