<?php
use yii\helpers\Html;
?>
<div class="activity-details">
    <p><strong><?= Yii::t('app', 'Job No:') ?></strong> <?= Html::encode($model->jobno) ?></p>
    <p><strong><?= Yii::t('app', 'Welder(s):') ?></strong> <?= Html::encode($model->welder) ?></p>
    <p><strong><?= Yii::t('app', 'Start Date:') ?></strong> <?= Html::encode($model->sdate) ?></p>
    <p><strong><?= Yii::t('app', 'End Date:') ?></strong> <?= Html::encode($model->edate) ?></p>
    <p><strong><?= Yii::t('app', 'Job Status:') ?></strong> <?= Html::encode($model->jobstatus) ?></p>
    <p><strong><?= Yii::t('app', 'Billing Status:') ?></strong> <?= Html::encode($model->billingstatus) ?></p>
    <?php if($model->type == 'welding') { ?>
        <p><strong><?= Yii::t('app', 'Comments:') ?></strong> <?= Html::encode($model->comments) ?></p>
    <?php }elseif($model->type == 'training') { ?>
        <p><strong><?= Yii::t('app', 'Company:') ?></strong> <?= Html::encode($model->data['Training']->company) ?></p>    
        <p><strong><?= Yii::t('app', 'Course:') ?></strong> <?= Html::encode($model->data['Training']->course) ?></p>    
    <?php } ?>
    <hr />
    <?= Html::a('Update', ['activities/update', 'id' => $model->id], ['class' => 'btn btn-primary', 'target' => '_blank']) ?>
    <?= Html::a('View', ['activities/view', 'id' => $model->id], ['class' => 'btn btn-primary', 'target' => '_blank']) ?>
</div>