<?php foreach($model->data as $key => $value){ ?>
    <?php if (is_array($value)){ ?>
        <?php foreach($value as $subkey => $subvalue){ ?>
            <div class="card">
                <div class="card-header">
                    <h4 class="card-title"><?= \yii\helpers\Inflector::camel2words($key) ?> - <?= $subvalue->user ?></h4>
                </div>
                <div class="card-body">
                    <div class=" row">
                        <?php foreach($subvalue->attributes as $attfield => $attvalue){ ?>
                            <label class="col-sm-3 col-form-label"><?= $subvalue->getAttributeLabel($attfield) ?></label>
                            <div class="col-sm-9">
                                <?= $subvalue->$attfield ?>
                            </div>
                        <?php } ?>
                    </div>
                </div>
            </div>
        <?php } ?>
    <?php } ?>
<?php } ?>