<?php

use yii\helpers\Html;
use yii\helpers\Url;
use yii\widgets\ActiveForm;
use frontend\models\Dtpdf;

?>
<?php $form = ActiveForm::begin(['options' => ['id' => 'form', 'enctype' => 'multipart/form-data', 'onLoad' => 'event1())']]); ?>

     <?= $model->id ?>
     <?php $form = ActiveForm::end([]); ?>
