<?php 
use yii\helpers\Html;

?>
<div class="card">
    <div class="card-header">
        Training
    </div>
    <div class="card-body">
        <div class="row">
            <div class="col-12">
                <?php foreach($dataModel as $attfield => $attvalue){ ?>
                    <?php if($attfield !== 'SharePointUrl'){ ?>
                        <?= $form->field($dataModel, $attfield)->textInput(['class' => 'form-control']) ?>
                        
                    <?php } ?>
                <?php } ?>
                <?php if(!empty($dataModel->SharePointUrl)){ ?>
                    <div class="form-group">
                        <?= Html::label('SharePoint URL:', 'sharepointurl', ['class' => 'control-label']) ?>
                        <?= Html::A('Folder', $dataModel->SharePointUrl, ['target' => '_blank']) ?>
                    </div>
                <?php } ?>
            </div>
        </div>
        <div class="row">
            <div class="col-12">
                <?= $form->field($model, 'customerpono')->textInput([]) ?>
                <?= $form->field($model, 'notes')->textarea(['rows' => 6]) ?>
            </div>
        </div>
    </div>
    
</div>