<?php
use yii\helpers\Html;
use common\widgets\GridView;
use kartik\export\ExportMenu;
use sjaakp\timeline\Timeline;
use frontend\models\Activies;
use frontend\controllers\activitiescontroller;
?>
<?php
    // define Timeline
    $t = Timeline::begin([
        'dataProvider' => $dataProvider,
        'attributes' => [
            'start' => 'starttime',
            'end' => 'finishtime',
            'text' => 'engineer',
            'caption' => 'company'
          ]
    ]);

    // define main Band
    $t->band([
        'width' => '60%',
        'intervalUnit' => Timeline::HOUR,
        'intervalPixels' => 100
        
        // layout not set, use default
    ]);

    // define secondary Band
    $t->band([
    	'width' => '50%',
        'intervalUnit' => Timeline::DAY,
        'intervalPixels' => 120,
    ]);
	$t->band([
        'width' => '20%',
        'intervalUnit' => Timeline::WEEK,
        'intervalPixels' => 120,
        'layout' => 'compact'
    ]);
    // complete definition
    Timeline::end();
?>